14.88. cdist-type__package_opkg(7) — cdist 4.8.1 documentation

# 14.88. cdist-type__package_opkg(7)

## 14.88.1. NAME

cdist-type__package_opkg - Manage packages with opkg

## 14.88.2. DESCRIPTION

opkg is usually used on OpenWRT to manage packages.

## 14.88.3. REQUIRED PARAMETERS

None

## 14.88.4. OPTIONAL PARAMETERS

name
  If supplied, use the name and not the object id as the package name.
state
  Either "present" or "absent", defaults to "present"

## 14.88.5. EXAMPLES

    # Ensure lsof is installed
    __package_opkg lsof --state present

    # Remove obsolete package
    __package_opkg dnsmasq --state absent

## 14.88.6. SEE ALSO

cdist-type__package(7)

## 14.88.7. AUTHORS

Giel van Schijndel <giel+cdist--@--mortis.eu>

## 14.88.8. COPYING

Copyright (C) 2012 Giel van Schijndel. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.